@@ -1,6 +1,8 @@
 # coding: utf-8
 import os
 import sys
+import string
+from shlex import shlex
 
 
 # Useful for very coarse version differentiation.
@@ -8,8 +10,10 @@ PY3 = sys.version_info[0] == 3
 
 if PY3:
     from configparser import ConfigParser
+    text_type = str
 else:
     from ConfigParser import SafeConfigParser as ConfigParser
+    text_type = unicode
 
 
 class UndefinedValueError(Exception):
@@ -113,14 +117,18 @@ class RepositoryEnv(RepositoryBase):
             if not line or line.startswith('#') or '=' not in line:
                 continue
             k, v = line.split('=', 1)
-            v = v.strip("'").strip('"')
+            k = k.strip()
+            v = v.strip().strip('\'"')
             self.data[k] = v
 
     def __contains__(self, key):
         return key in self.data or key in os.environ
 
     def get(self, key):
-        return self.data.get(key) or os.environ[key]
+        try:
+            return self.data[key]
+        except KeyError:
+            return os.environ[key]
 
 
 class RepositoryShell(RepositoryBase):
@@ -193,3 +201,33 @@ class AutoConfig(object):
 # A pré-instantiated AutoConfig to improve decouple's usability
 # now just import config and start using with no configuration.
 config = AutoConfig()
+
+
+# Helpers
+
+class Csv(object):
+    """
+    Produces a csv parser that return a list of transformed elements.
+    """
+
+    def __init__(self, cast=text_type, delimiter=',', strip=string.whitespace):
+        """
+        Parameters:
+        cast -- callable that transforms the item just before it's added to the list.
+        delimiter -- string of delimiters chars passed to shlex.
+        strip -- string of non-relevant characters to be passed to str.strip after the split.
+        """
+        self.cast = cast
+        self.delimiter = delimiter
+        self.strip = strip
+
+    def __call__(self, value):
+        """The actual transformation"""
+        transform = lambda s: self.cast(s.strip(self.strip))
+
+        splitter = shlex(value, posix=True)
+        splitter.whitespace = self.delimiter
+        splitter.whitespace_split = True
+
+        return [transform(s) for s in splitter]
+
